@@ -83,7 +83,7 @@ impl fmt::Debug for BigRat {
 
 impl Ord for BigRat {
 	fn cmp(&self, other: &Self) -> cmp::Ordering {
-		let int = &crate::interrupt::Never::default();
+		let int = &crate::interrupt::Never;
 		let diff = self.clone().add(-other.clone(), int).unwrap();
 		if diff.num == 0.into() {
 			cmp::Ordering::Equal
@@ -111,7 +111,7 @@ impl Eq for BigRat {}
 
 impl hash::Hash for BigRat {
 	fn hash<H: hash::Hasher>(&self, state: &mut H) {
-		let int = &crate::interrupt::Never::default();
+		let int = &crate::interrupt::Never;
 		if let Ok(res) = self.clone().simplify(int) {
 			// don't hash the sign
 			res.num.hash(state);
@@ -136,6 +136,10 @@ impl BigRat {
 		})
 	}
 
+	pub(crate) fn is_integer(&self) -> bool {
+		self.den == 1.into()
+	}
+
 	pub(crate) fn try_as_usize<I: Interrupt>(mut self, int: &I) -> Result<usize, FendError> {
 		if self.sign == Sign::Negative && self.num != 0.into() {
 			return Err(FendError::NegativeNumbersNotAllowed);
@@ -148,12 +152,15 @@ impl BigRat {
 	}
 
 	pub(crate) fn into_f64<I: Interrupt>(mut self, int: &I) -> Result<f64, FendError> {
+		if self.is_definitely_zero() {
+			return Ok(0.0);
+		}
 		self = self.simplify(int)?;
 		let positive_result = self.num.as_f64() / self.den.as_f64();
-		if self.sign == Sign::Positive {
-			Ok(positive_result)
-		} else {
+		if self.sign == Sign::Negative {
 			Ok(-positive_result)
+		} else {
+			Ok(positive_result)
 		}
 	}
 
@@ -213,6 +220,10 @@ impl BigRat {
 		Self::from_f64(f64::atan(self.into_f64(int)?), int)
 	}
 
+	pub(crate) fn atan2<I: Interrupt>(self, rhs: Self, int: &I) -> Result<Self, FendError> {
+		Self::from_f64(f64::atan2(self.into_f64(int)?, rhs.into_f64(int)?), int)
+	}
+
 	pub(crate) fn sinh<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
 		Self::from_f64(f64::sinh(self.into_f64(int)?), int)
 	}
@@ -253,7 +264,7 @@ impl BigRat {
 	}
 
 	// For all logs: value must be greater than 0
-	pub(crate) fn ln<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
+	pub(crate) fn ln<I: Interrupt>(self, int: &I) -> Result<Exact<Self>, FendError> {
 		if self <= 0.into() {
 			return Err(out_of_range(
 				self.fm(int)?,
@@ -263,7 +274,13 @@ impl BigRat {
 				},
 			));
 		}
-		Self::from_f64(f64::ln(self.into_f64(int)?), int)
+		if self == 1.into() {
+			return Ok(Exact::new(0.into(), true));
+		}
+		Ok(Exact::new(
+			Self::from_f64(f64::ln(self.into_f64(int)?), int)?,
+			false,
+		))
 	}
 
 	pub(crate) fn log2<I: Interrupt>(self, int: &I) -> Result<Self, FendError> {
@@ -933,6 +950,16 @@ impl BigRat {
 		low_bound.add(high_bound, int)?.div(&2.into(), int)
 	}
 
+	pub(crate) fn exp<I: Interrupt>(self, int: &I) -> Result<Exact<Self>, FendError> {
+		if self.num == 0.into() {
+			return Ok(Exact::new(Self::from(1), true));
+		}
+		Ok(Exact::new(
+			Self::from_f64(self.into_f64(int)?.exp(), int)?,
+			false,
+		))
+	}
+
 	// the boolean indicates whether or not the result is exact
 	// n must be an integer
 	pub(crate) fn root_n<I: Interrupt>(self, n: &Self, int: &I) -> Result<Exact<Self>, FendError> {
@@ -1253,7 +1280,7 @@ mod tests {
 
 	#[test]
 	fn test_addition() -> Result<(), FendError> {
-		let int = &crate::interrupt::Never::default();
+		let int = &crate::interrupt::Never;
 		let two = BigRat::from(2);
 		assert_eq!(two.clone().add(two, int)?, BigRat::from(4));
 		Ok(())
